@@ -33,7 +33,7 @@
 
 /* Solaris is an all-or-nothing deal, all this stuff comes out of 
    one structure, so we don't need to dick around with the format much */
-static char Format[] = "iiiiiiiillllllllslssss";
+static char Format[] = "iiiiiiiillllliilllslssss";
 
 /* Mapping of field to type */
 static char* Fields[] = {
@@ -52,6 +52,8 @@ static char* Fields[] = {
   "flags",
   "time",
   "ctime",
+  "timensec",
+  "ctimensec",
   "size",
   "rss",
   "wchan",
